rtransparency-package: rtransparency: Identify indicators of transparency in the...

rtransparency-packageR Documentation

rtransparency: Identify indicators of transparency in the biomedical literature

Description

Detects and extracts eight indicators of transparency (conflicts of interest, funding, protocol registration, novelty, replication, data sharing, code sharing, and disclosure of generative-AI use) from PubMed Central XML or plain-text articles. For each indicator it returns a boolean prediction and the statement that triggered it. This package builds on the original rtransparent tool of Serghiou et al. (2021).

Author(s)

Maintainer: Ahmad Sofi-Mahmudi a.sofimahmudi@gmail.com (ORCID)

Authors:

See Also

Useful links:


rtransparency documentation built on July 1, 2026, 9:07 a.m.