Identify and extract Data and Code sharing from a list of PMC XML files.
Source:R/rt_data_code_pmc.R
rt_data_code_pmc_list.RdTakes a list of PMC XML files and returns data related to the presence of Data or Code, including whether Data or Code have been shared. If Data or Code exist, it will extract the relevant text for each.
Arguments
- filenames
A list of the PMC XML filenames as strings.
- remove_ns
TRUE if an XML namespace exists, else FALSE (default).
- specificity
Retained for backward compatibility; see
rt_data_code_pmc.
Examples
# \donttest{
# Paths to PMC XML files
filepath <- system.file(
"extdata", "PMID32171256-PMC7071725.xml", package = "rtransparency"
)
filepaths <- list(filepath)
# Identify and extract indicators of data and code sharing
results_table <- rt_data_code_pmc_list(filepaths, remove_ns = TRUE)
# }