View source: R/rt_data_code_pmc.R
| rt_data_code_pmc_list | R Documentation |
Takes a list of PMC XML files and returns data related to the presence of Data or Code, including whether Data or Code have been shared. If Data or Code exist, it will extract the relevant text for each.
rt_data_code_pmc_list(filenames, remove_ns = TRUE, specificity = "low")
filenames |
A list of the PMC XML filenames as strings. |
remove_ns |
TRUE if an XML namespace exists, else FALSE (default). |
specificity |
Retained for backward compatibility; see
|
A dataframe of results, one row per file.
# Paths to PMC XML files
filepath <- system.file(
"extdata", "PMID32171256-PMC7071725.xml", package = "rtransparency"
)
filepaths <- list(filepath)
# Identify and extract indicators of data and code sharing
results_table <- rt_data_code_pmc_list(filepaths, remove_ns = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.