| rt_meta_pmc | R Documentation |
Reads a PMC XML file and returns its metadata as a one-row data frame: journal, publisher, article title, authors and affiliations, identifiers (PMID, PMCID, DOI), publication dates, and figure / table / reference counts.
rt_meta_pmc(filename, remove_ns = FALSE)
filename |
The path to the PMC XML file as a string. |
remove_ns |
TRUE if an XML namespace should be removed, else FALSE (default). |
A one-row tibble of metadata. The column 'is_success' indicates whether the file was parsed successfully.
filepath <- system.file(
"extdata", "PMID32171256-PMC7071725.xml", package = "rtransparency"
)
rt_meta_pmc(filepath, remove_ns = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.