| rtransparency-package | R Documentation |
Detects and extracts eight indicators of transparency (conflicts of interest, funding, protocol registration, novelty, replication, data sharing, code sharing, and disclosure of generative-AI use) from PubMed Central XML or plain-text articles. For each indicator it returns a boolean prediction and the statement that triggered it. This package builds on the original rtransparent tool of Serghiou et al. (2021).
Maintainer: Ahmad Sofi-Mahmudi a.sofimahmudi@gmail.com (ORCID)
Authors:
Ahmad Sofi-Mahmudi a.sofimahmudi@gmail.com (ORCID)
Stylianos Serghiou stelios.serghiou@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.